@@ -1,5 +1,5 @@
 package ZMQ::Raw::Socket;
-$ZMQ::Raw::Socket::VERSION = '0.01';
+$ZMQ::Raw::Socket::VERSION = '0.02';
 use strict;
 use warnings;
 use Carp;
@@ -29,7 +29,7 @@ ZMQ::Raw::Socket - ZeroMQ Socket class
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -50,6 +50,10 @@ endpoint is a string consisting of a transport:// followed by an address. The
 transport specifies the underlying protocol to use, whereas the address
 specifies the transport-specific address to bind to. TODO: list transports
 
+=head2 unbind( $endpoint )
+
+Unbind the socket from the endpoint.
+
 =head2 connect( $endpoint )
 
 Connect the socket to an endpoint which accepts incoming connections. TODO
@@ -74,9 +78,9 @@ Receive a message. If C<$size> does not have enough space to store a full
 message, it will be truncated. If there are no messages available the method
 will block until the request can be satisfied. TODO: list flags
 
-=head2 recvmsg( $msg, $flags = 0)
+=head2 recvmsg( $flags = 0)
 
-Receive a message part and store it int C<$msg>.
+Receive a message part. Returns a L<C<ZMQ::Raw::Message>> object.
 
 =head2 setsockopt( $option, $value )
 
